@@ -26,7 +26,7 @@ from gi.repository import Gtk, GLib
 
 _shell = GnomeShellFactory().get_shell()
 _shell_loaded = _shell is not None
-            
+
 class ShowWindowButtons(GSettingsSwitchTweakValue):
 
     def __init__(self, name, value, **options):
@@ -39,18 +39,27 @@ class ShowWindowButtons(GSettingsSwitchTweakValue):
                                            **options)
     def get_active(self):
         return self.value in self.settings.get_string(self.key_name)
-            
+
     def set_active(self, v):
         val = self.settings.get_string(self.key_name)
-        if v:
-            if val == ":close":
-                val = val.replace(":", ":"+self.value+",")
-            else:
-                val = ":minimize,maximize,close"
-        else:
-            val = val.replace(self.value+",", "")
 
-        self.settings.set_string(self.key_name, val)
+        (left, colon, right) = val.partition(":")
+        rsplit = right.split(",")
+
+        if v:
+            rsplit.append(self.value)
+        else:
+            rsplit.remove(self.value)
+
+        def sort_buttons(x, y):
+            order = ["minimize", "maximize", "close"];
+            if x in order and y in order:
+                return order.index(x) - order.index(y)
+            else:
+                return 0
+        rsplit.sort(cmp=sort_buttons)
+
+        self.settings.set_string(self.key_name, left + colon + ",".join(rsplit))
 
 class WindowScalingFactorTweak(Gtk.Box, Tweak):
     def __init__(self, **options):
@@ -123,10 +132,10 @@ class WindowScalingFactorTweak(Gtk.Box, Tweak):
         self._close()
         self._dialog.destroy()
 
-TWEAK_GROUPS = [ 
+TWEAK_GROUPS = [
     ListBoxTweakGroup(TWEAK_GROUP_WINDOWS,
         GSettingsSwitchTweak(_("Attached Modal Dialogs"),"org.gnome.mutter", "attach-modal-dialogs"),
-        GSettingsSwitchTweak(_("Automatically Raise Windows"),"org.gnome.desktop.wm.preferences", "raise-on-click"),
+        GSettingsSwitchTweak(_("Automatically Raise Windows"),"org.gnome.desktop.wm.preferences", "auto-raise"),
         GSettingsSwitchTweak(_("Resize with Secondary-click"),"org.gnome.desktop.wm.preferences", "resize-with-right-button"),
         GSettingsComboTweak(_("Window Action Key"),
                         "org.gnome.desktop.wm.preferences",
